import pandas as pd
from opa_tools.config import BENCHMARK_DIR, validate_benchmark_dir
import yaml


def _process_dct(dct, prefix="", valid_types=(str, int, float)):
    return {
        f"{prefix}{key}": [value if isinstance(value, valid_types) else str(value)]
        for key, value
        in dct.items()
    }

def get_request_df(*dates):
    validate_benchmark_dir()
    directories = sorted(path.name for path in BENCHMARK_DIR.iterdir()) # type: ignore
    if dates:
        directories = list(filter(
            lambda directory: any(directory.startswith(date) for date in dates),
            directories
        ))
    request_df = pd.DataFrame()
    for date in directories:
        directory_date = BENCHMARK_DIR / date # type: ignore
        for benchmark in sorted(directory_date.iterdir()):
            with (
                open(benchmark / "date.txt", "r") as date_file,
                open(benchmark / "additional" / "gsvrequest.yaml", "r") as gsv_request_file,
                open(benchmark / "additional" / "oparequest.yaml", "r") as opa_request_file,
            ):
                gsv_dict = yaml.safe_load(gsv_request_file)
                opa_dict = yaml.safe_load(opa_request_file)
                dct = {
                    "date": date_file.read(),
                    "bname": benchmark.name,
                    **_process_dct(gsv_dict, prefix="gsv_"),
                    **_process_dct(opa_dict, prefix="opa_"),
                }
                entry = pd.DataFrame.from_dict(dct)
                request_df = pd.concat([request_df, entry], ignore_index=True)
    return request_df

