from typing import Dict, Optional, Tuple, Union
import yaml

from opa_tools.config import REQUEST_DIR

def get_request(num: int, kind: Optional[str] = None) -> Union[Tuple[Dict, Dict], Dict]:
    def get(num: int, kind: str) -> Dict:
        if kind not in ("opa", "gsv"):
            raise AssertionError(
                f"kind must be either 'opa' or 'gsv', but was '{kind}'."
            )
        request_path = REQUEST_DIR / f"{num:02d}" / f"{kind}.yml"
        with open(request_path, "r", encoding="utf-8") as rf:
            return yaml.safe_load(rf)
    if kind is None:
        return (
            get(num=num, kind="gsv"),
            get(num=num, kind="opa"),
        )
    return get(num=num, kind=kind)


